@@ -1,21 +1,21 @@
 # coding: utf-8
 
-from sqlalchemy.test.testing import eq_
+from test.lib.testing import eq_
 from sqlalchemy import *
 from sqlalchemy import types as sqltypes, exc
 from sqlalchemy.sql import table, column
-from sqlalchemy.test import *
-from sqlalchemy.test.testing import eq_, assert_raises, assert_raises_message
-from sqlalchemy.test.engines import testing_engine
+from test.lib import *
+from test.lib.testing import eq_, assert_raises, assert_raises_message
+from test.lib.engines import testing_engine
 from sqlalchemy.dialects.oracle import cx_oracle, base as oracle
 from sqlalchemy.engine import default
 from sqlalchemy.util import jython
-from decimal import Decimal
+from sqlalchemy.util.compat import decimal
 import datetime
 import os
 
 
-class OutParamTest(TestBase, AssertsExecutionResults):
+class OutParamTest(fixtures.TestBase, AssertsExecutionResults):
     __only_on__ = 'oracle+cx_oracle'
 
     @classmethod
@@ -48,7 +48,7 @@ create or replace procedure foo(x_in IN number, x_out OUT number, y_out OUT numb
          testing.db.execute("DROP PROCEDURE foo")
 
 
-class CompileTest(TestBase, AssertsCompiledSQL):
+class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
 
     __dialect__ = oracle.OracleDialect()
 
@@ -403,7 +403,20 @@ class CompileTest(TestBase, AssertsCompiledSQL):
                             'SELECT t1.c1, t1.c2, t1.c3 FROM t1 MINUS '
                             'SELECT t2.c1, t2.c2, t2.c3 FROM t2')
 
-class CompatFlagsTest(TestBase, AssertsCompiledSQL):
+    def test_no_paren_fns(self):
+        for fn, expected in [
+            (func.uid(), "uid"),
+            (func.UID(), "UID"),
+            (func.sysdate(), "sysdate"),
+            (func.row_number(), "row_number()"),
+            (func.rank(), "rank()"),
+            (func.now(), "CURRENT_TIMESTAMP"),
+            (func.current_timestamp(), "CURRENT_TIMESTAMP"),
+            (func.user(), "USER"),
+        ]:
+            self.assert_compile(fn, expected)
+
+class CompatFlagsTest(fixtures.TestBase, AssertsCompiledSQL):
     __only_on__ = 'oracle'
 
     def test_ora8_flags(self):
@@ -436,6 +449,7 @@ class CompatFlagsTest(TestBase, AssertsCompiledSQL):
 
     def test_default_flags(self):
         """test with no initialization or server version info"""
+
         dialect = oracle.dialect(dbapi=testing.db.dialect.dbapi)
         assert dialect._supports_char_length
         assert dialect._supports_nchar
@@ -458,7 +472,7 @@ class CompatFlagsTest(TestBase, AssertsCompiledSQL):
         self.assert_compile(UnicodeText(),"NCLOB",dialect=dialect)
 
 
-class MultiSchemaTest(TestBase, AssertsCompiledSQL):
+class MultiSchemaTest(fixtures.TestBase, AssertsCompiledSQL):
     __only_on__ = 'oracle'
 
     @classmethod
@@ -616,7 +630,7 @@ drop synonym test_schema.ptable;
         select([parent,
                child]).select_from(parent.join(child)).execute().fetchall()
 
-class ConstraintTest(TestBase):
+class ConstraintTest(fixtures.TestBase):
 
     __only_on__ = 'oracle'
 
@@ -641,7 +655,7 @@ class ConstraintTest(TestBase):
                     onupdate='CASCADE'))
         assert_raises(exc.SAWarning, bat.create)
 
-class TypesTest(TestBase, AssertsCompiledSQL):
+class TypesTest(fixtures.TestBase, AssertsCompiledSQL):
     __only_on__ = 'oracle'
     __dialect__ = oracle.OracleDialect()
 
@@ -732,6 +746,7 @@ class TypesTest(TestBase, AssertsCompiledSQL):
 
     @testing.provide_metadata
     def test_rowid(self):
+        metadata = self.metadata
         t = Table('t1', metadata,
             Column('x', Integer)
         )
@@ -817,12 +832,12 @@ class TypesTest(TestBase, AssertsCompiledSQL):
             ):
                 for i, (val, type_) in enumerate((
                     (1, int),
-                    (Decimal("5.2"), Decimal),
+                    (decimal.Decimal("5.2"), decimal.Decimal),
                     (6.5, float),
                     (8.5, float),
                     (9.5, float),
                     (12, int),
-                    (Decimal("14.85"), Decimal),
+                    (decimal.Decimal("14.85"), decimal.Decimal),
                     (15.76, float),
                 )):
                     eq_(row[i], val)
@@ -840,6 +855,8 @@ class TypesTest(TestBase, AssertsCompiledSQL):
 
         """
 
+        metadata = self.metadata
+
         # this test requires cx_oracle 5
 
         foo = Table('foo', metadata,
@@ -852,8 +869,8 @@ class TypesTest(TestBase, AssertsCompiledSQL):
         foo.create()
 
         foo.insert().execute(
-            {'idata':5, 'ndata':Decimal("45.6"), 'ndata2':Decimal("45.0"), 
-                    'nidata':Decimal('53'), 'fdata':45.68392},
+            {'idata':5, 'ndata':decimal.Decimal("45.6"), 'ndata2':decimal.Decimal("45.0"), 
+                    'nidata':decimal.Decimal('53'), 'fdata':45.68392},
         )
 
         stmt = """
@@ -868,10 +885,10 @@ class TypesTest(TestBase, AssertsCompiledSQL):
 
 
         row = testing.db.execute(stmt).fetchall()[0]
-        eq_([type(x) for x in row], [int, Decimal, Decimal, int, float])
+        eq_([type(x) for x in row], [int, decimal.Decimal, decimal.Decimal, int, float])
         eq_(
             row, 
-            (5, Decimal('45.6'), Decimal('45'), 53, 45.683920000000001)
+            (5, decimal.Decimal('45.6'), decimal.Decimal('45'), 53, 45.683920000000001)
         )
 
         # with a nested subquery, 
@@ -895,10 +912,10 @@ class TypesTest(TestBase, AssertsCompiledSQL):
         FROM dual
         """
         row = testing.db.execute(stmt).fetchall()[0]
-        eq_([type(x) for x in row], [int, Decimal, int, int, Decimal])
+        eq_([type(x) for x in row], [int, decimal.Decimal, int, int, decimal.Decimal])
         eq_(
             row, 
-            (5, Decimal('45.6'), 45, 53, Decimal('45.68392'))
+            (5, decimal.Decimal('45.6'), 45, 53, decimal.Decimal('45.68392'))
         )
 
         row = testing.db.execute(text(stmt, 
@@ -909,9 +926,9 @@ class TypesTest(TestBase, AssertsCompiledSQL):
                                         'nidata':Numeric(5, 0),
                                         'fdata':Float()
                                 })).fetchall()[0]
-        eq_([type(x) for x in row], [int, Decimal, Decimal, Decimal, float])
+        eq_([type(x) for x in row], [int, decimal.Decimal, decimal.Decimal, decimal.Decimal, float])
         eq_(row, 
-            (5, Decimal('45.6'), Decimal('45'), Decimal('53'), 45.683920000000001)
+            (5, decimal.Decimal('45.6'), decimal.Decimal('45'), decimal.Decimal('53'), 45.683920000000001)
         )
 
         stmt = """
@@ -938,8 +955,8 @@ class TypesTest(TestBase, AssertsCompiledSQL):
         WHERE ROWNUM >= 0) anon_1
         """
         row =testing.db.execute(stmt).fetchall()[0]
-        eq_([type(x) for x in row], [int, Decimal, int, int, Decimal])
-        eq_(row, (5, Decimal('45.6'), 45, 53, Decimal('45.68392')))
+        eq_([type(x) for x in row], [int, decimal.Decimal, int, int, decimal.Decimal])
+        eq_(row, (5, decimal.Decimal('45.6'), 45, 53, decimal.Decimal('45.68392')))
 
         row = testing.db.execute(text(stmt, 
                                 typemap={
@@ -949,9 +966,9 @@ class TypesTest(TestBase, AssertsCompiledSQL):
                                         'anon_1_nidata':Numeric(5, 0), 
                                         'anon_1_fdata':Float()
                                 })).fetchall()[0]
-        eq_([type(x) for x in row], [int, Decimal, Decimal, Decimal, float])
+        eq_([type(x) for x in row], [int, decimal.Decimal, decimal.Decimal, decimal.Decimal, float])
         eq_(row, 
-            (5, Decimal('45.6'), Decimal('45'), Decimal('53'), 45.683920000000001)
+            (5, decimal.Decimal('45.6'), decimal.Decimal('45'), decimal.Decimal('53'), 45.683920000000001)
         )
 
         row = testing.db.execute(text(stmt, 
@@ -962,9 +979,9 @@ class TypesTest(TestBase, AssertsCompiledSQL):
                                         'anon_1_nidata':Numeric(5, 0, asdecimal=False), 
                                         'anon_1_fdata':Float(asdecimal=True)
                                 })).fetchall()[0]
-        eq_([type(x) for x in row], [int, float, float, float, Decimal])
+        eq_([type(x) for x in row], [int, float, float, float, decimal.Decimal])
         eq_(row, 
-            (5, 45.6, 45, 53, Decimal('45.68392'))
+            (5, 45.6, 45, 53, decimal.Decimal('45.68392'))
         )
 
 
@@ -993,7 +1010,7 @@ class TypesTest(TestBase, AssertsCompiledSQL):
         finally:
             metadata.drop_all()
 
-    def test_reflect_all_types_schema(self):
+    def test_reflect_raw(self):
         types_table = Table('all_types', MetaData(testing.db),
             Column('owner', String(30), primary_key=True),
             Column('type_name', String(30), primary_key=True),
@@ -1002,45 +1019,31 @@ class TypesTest(TestBase, AssertsCompiledSQL):
         for row in types_table.select().execute().fetchall():
             [row[k] for k in row.keys()]
 
-    def test_raw_compile(self):
-        self.assert_compile(oracle.RAW(), "RAW")
-        self.assert_compile(oracle.RAW(35), "RAW(35)")
-
-    @testing.provide_metadata
-    def test_raw_roundtrip(self):
-        raw_table = Table('raw', metadata,
-            Column('id', Integer, primary_key=True),
-            Column('data', oracle.RAW(35))
-        )
-        metadata.create_all()
-        testing.db.execute(raw_table.insert(), id=1, data="ABCDEF")
-        eq_(
-            testing.db.execute(raw_table.select()).first(),
-            (1, "ABCDEF")
-        )
-
-    @testing.provide_metadata
     def test_reflect_nvarchar(self):
+        metadata = MetaData(testing.db)
         t = Table('t', metadata,
             Column('data', sqltypes.NVARCHAR(255))
         )
         metadata.create_all()
-        m2 = MetaData(testing.db)
-        t2 = Table('t', m2, autoload=True)
-        assert isinstance(t2.c.data.type, sqltypes.NVARCHAR)
+        try:
+            m2 = MetaData(testing.db)
+            t2 = Table('t', m2, autoload=True)
+            assert isinstance(t2.c.data.type, sqltypes.NVARCHAR)
 
-        if testing.against('oracle+cx_oracle'):
-            # nvarchar returns unicode natively.  cx_oracle
-            # _OracleNVarChar type should be at play here.
-            assert isinstance(
-                t2.c.data.type.dialect_impl(testing.db.dialect), 
-                cx_oracle._OracleNVarChar)
+            if testing.against('oracle+cx_oracle'):
+                # nvarchar returns unicode natively.  cx_oracle
+                # _OracleNVarChar type should be at play here.
+                assert isinstance(
+                    t2.c.data.type.dialect_impl(testing.db.dialect), 
+                    cx_oracle._OracleNVarChar)
 
-        data = u'm’a réveillé.'
-        t2.insert().execute(data=data)
-        res = t2.select().execute().first()['data']
-        eq_(res, data)
-        assert isinstance(res, unicode)
+            data = u'm’a réveillé.'
+            t2.insert().execute(data=data)
+            res = t2.select().execute().first()['data']
+            eq_(res, data)
+            assert isinstance(res, unicode)
+        finally:
+            metadata.drop_all()
 
     def test_char_length(self):
         self.assert_compile(VARCHAR(50),"VARCHAR(50 CHAR)")
@@ -1085,7 +1088,7 @@ class TypesTest(TestBase, AssertsCompiledSQL):
             testing.db.execute("DROP TABLE Z_TEST")
 
     @testing.fails_on('+zxjdbc', 'auto_convert_lobs not applicable')
-    def test_lobs_without_convert(self):
+    def test_raw_lobs(self):
         engine = testing_engine(options=dict(auto_convert_lobs=False))
         metadata = MetaData()
         t = Table("z_test", metadata, Column('id', Integer, primary_key=True), 
@@ -1101,7 +1104,7 @@ class TypesTest(TestBase, AssertsCompiledSQL):
         finally:
             t.drop(engine)
 
-class EuroNumericTest(TestBase):
+class EuroNumericTest(fixtures.TestBase):
     """test the numeric output_type_handler when using non-US locale for NLS_LANG."""
 
     __only_on__ = 'oracle+cx_oracle'
@@ -1120,12 +1123,13 @@ class EuroNumericTest(TestBase):
 
     @testing.provide_metadata
     def test_output_type_handler(self):
+        metadata = self.metadata
         for stmt, exp, kw in [
-            ("SELECT 0.1 FROM DUAL", Decimal("0.1"), {}),
+            ("SELECT 0.1 FROM DUAL", decimal.Decimal("0.1"), {}),
             ("SELECT 15 FROM DUAL", 15, {}),
-            ("SELECT CAST(15 AS NUMERIC(3, 1)) FROM DUAL", Decimal("15"), {}),
-            ("SELECT CAST(0.1 AS NUMERIC(5, 2)) FROM DUAL", Decimal("0.1"), {}),
-            ("SELECT :num FROM DUAL", Decimal("2.5"), {'num':Decimal("2.5")})
+            ("SELECT CAST(15 AS NUMERIC(3, 1)) FROM DUAL", decimal.Decimal("15"), {}),
+            ("SELECT CAST(0.1 AS NUMERIC(5, 2)) FROM DUAL", decimal.Decimal("0.1"), {}),
+            ("SELECT :num FROM DUAL", decimal.Decimal("2.5"), {'num':decimal.Decimal("2.5")})
         ]:
             test_exp = self.engine.scalar(stmt, **kw)
             eq_(
@@ -1135,7 +1139,7 @@ class EuroNumericTest(TestBase):
             assert type(test_exp) is type(exp)
 
 
-class DontReflectIOTTest(TestBase):
+class DontReflectIOTTest(fixtures.TestBase):
     """test that index overflow tables aren't included in
     table_names."""
 
@@ -1166,7 +1170,7 @@ class DontReflectIOTTest(TestBase):
             set(['admin_docindex'])
         )
 
-class BufferedColumnTest(TestBase, AssertsCompiledSQL):
+class BufferedColumnTest(fixtures.TestBase, AssertsCompiledSQL):
     __only_on__ = 'oracle'
 
     @classmethod
@@ -1200,7 +1204,7 @@ class BufferedColumnTest(TestBase, AssertsCompiledSQL):
         result = eng.execute(binary_table.select()).fetchall()
         eq_(result, [(i, stream) for i in range(1, 11)])
 
-class UnsupportedIndexReflectTest(TestBase):
+class UnsupportedIndexReflectTest(fixtures.TestBase):
     __only_on__ = 'oracle'
 
     def setup(self):
@@ -1220,7 +1224,7 @@ class UnsupportedIndexReflectTest(TestBase):
         m2 = MetaData(testing.db)
         t2 = Table('test_index_reflect', m2, autoload=True)
 
-class RoundTripIndexTest(TestBase):
+class RoundTripIndexTest(fixtures.TestBase):
     __only_on__ = 'oracle'
 
     def test_basic(self):
@@ -1294,7 +1298,7 @@ class RoundTripIndexTest(TestBase):
 
 
 
-class SequenceTest(TestBase, AssertsCompiledSQL):
+class SequenceTest(fixtures.TestBase, AssertsCompiledSQL):
 
     def test_basic(self):
         seq = Sequence('my_seq_no_schema')
@@ -1309,7 +1313,7 @@ class SequenceTest(TestBase, AssertsCompiledSQL):
             == '"Some_Schema"."My_Seq"'
 
 
-class ExecuteTest(TestBase):
+class ExecuteTest(fixtures.TestBase):
 
     __only_on__ = 'oracle'
 
@@ -1329,6 +1333,7 @@ class ExecuteTest(TestBase):
 
     @testing.provide_metadata
     def test_limit_offset_for_update(self):
+        metadata = self.metadata
         # oracle can't actually do the ROWNUM thing with FOR UPDATE
         # very well.
 
@@ -1361,11 +1366,12 @@ class ExecuteTest(TestBase):
         )
 
 
-class UnicodeSchemaTest(TestBase):
+class UnicodeSchemaTest(fixtures.TestBase):
     __only_on__ = 'oracle'
 
     @testing.provide_metadata
     def test_quoted_column_non_unicode(self):
+        metadata = self.metadata
         table=Table("atable", metadata,
             Column("_underscorecolumn", Unicode(255), primary_key=True),
         )
@@ -1381,6 +1387,7 @@ class UnicodeSchemaTest(TestBase):
 
     @testing.provide_metadata
     def test_quoted_column_unicode(self):
+        metadata = self.metadata
         table=Table("atable", metadata,
             Column(u"méil", Unicode(255), primary_key=True),
         )
