@@ -1,4 +1,4 @@
-from sqlalchemy.test.testing import eq_, assert_raises, assert_raises_message
+from test.lib.testing import eq_, assert_raises, assert_raises_message
 from sqlalchemy import *
 from sqlalchemy.orm import *
 from sqlalchemy.orm import interfaces
@@ -6,15 +6,16 @@ from sqlalchemy import exc as sa_exc
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.engine import default
 
-from sqlalchemy.test import AssertsCompiledSQL, testing
-from test.orm import _base, _fixtures
-from sqlalchemy.test.testing import eq_
-from sqlalchemy.test.schema import Table, Column
+from test.lib import AssertsCompiledSQL, testing
+from test.lib import fixtures
+from test.orm import _fixtures
+from test.lib.testing import eq_
+from test.lib.schema import Table, Column
 
-class Company(_fixtures.Base):
+class Company(fixtures.ComparableEntity):
     pass
 
-class Person(_fixtures.Base):
+class Person(fixtures.ComparableEntity):
     pass
 class Engineer(Person):
     pass
@@ -23,14 +24,14 @@ class Manager(Person):
 class Boss(Manager):
     pass
 
-class Machine(_fixtures.Base):
+class Machine(fixtures.ComparableEntity):
     pass
 
-class Paperwork(_fixtures.Base):
+class Paperwork(fixtures.ComparableEntity):
     pass
 
 def _produce_test(select_type):
-    class PolymorphicQueryTest(_base.MappedTest, AssertsCompiledSQL):
+    class PolymorphicQueryTest(fixtures.MappedTest, AssertsCompiledSQL):
         run_inserts = 'once'
         run_setup_mappers = 'once'
         run_deletes = None
@@ -237,7 +238,7 @@ def _produce_test(select_type):
             e = aliased(Person)
             c = aliased(Company)
 
-            q = sess.query(Company, Person, c, e).join((Person, Company.employees)).join((e, c.employees)).\
+            q = sess.query(Company, Person, c, e).join(Person, Company.employees).join(e, c.employees).\
                     filter(Person.name=='dilbert').filter(e.name=='wally')
 
             eq_(q.count(), 1)
@@ -358,38 +359,68 @@ def _produce_test(select_type):
             )
 
             eq_(
-                sess.query(Manager.name).join((Paperwork, Manager.paperwork)).order_by(Manager.name).all(),
+                sess.query(Manager.name).join(Paperwork, Manager.paperwork).order_by(Manager.name).all(),
                 [(u'dogbert',), (u'dogbert',), (u'pointy haired boss',)]
             )
 
             eq_(
-                sess.query(Person.name).join((Paperwork, Person.paperwork)).order_by(Person.name).all(),
+                sess.query(Person.name).join(Paperwork, Person.paperwork).order_by(Person.name).all(),
                 [(u'dilbert',), (u'dilbert',), (u'dogbert',), (u'dogbert',), (u'pointy haired boss',), (u'vlad',), (u'wally',), (u'wally',)]
             )
 
+            # Load Person.name, joining from Person -> paperwork, get all
+            # the people.
             eq_(
-                sess.query(Person.name).join((paperwork, Manager.person_id==paperwork.c.person_id)).order_by(Person.name).all(),
+                sess.query(Person.name).join(paperwork, Person.person_id==paperwork.c.person_id).order_by(Person.name).all(),
                 [(u'dilbert',), (u'dilbert',), (u'dogbert',), (u'dogbert',), (u'pointy haired boss',), (u'vlad',), (u'wally',), (u'wally',)]
             )
 
+            # same, on manager.  get only managers.
             eq_(
-                sess.query(Manager).join((Paperwork, Manager.paperwork)).order_by(Manager.name).all(),
+                sess.query(Manager.name).join(paperwork, Manager.person_id==paperwork.c.person_id).order_by(Person.name).all(),
+                [(u'dogbert',), (u'dogbert',), (u'pointy haired boss',)]
+            )
+
+            if select_type == '':
+                # this now raises, due to [ticket:1892].  Manager.person_id is now the "person_id" column on Manager.
+                # the SQL is incorrect.
+                assert_raises(
+                    sa_exc.DBAPIError,
+                    sess.query(Person.name).join(paperwork, Manager.person_id==paperwork.c.person_id).order_by(Person.name).all,
+                )
+            elif select_type == 'Unions':
+                # with the union, not something anyone would really be using here, it joins to 
+                # the full result set.  This is 0.6's behavior and is more or less wrong.
+                eq_(
+                    sess.query(Person.name).join(paperwork, Manager.person_id==paperwork.c.person_id).order_by(Person.name).all(),
+                    [(u'dilbert',), (u'dilbert',), (u'dogbert',), (u'dogbert',), (u'pointy haired boss',), (u'vlad',), (u'wally',), (u'wally',)]
+                )
+            else:
+                # when a join is present and managers.person_id is available, you get the managers.
+                eq_(
+                    sess.query(Person.name).join(paperwork, Manager.person_id==paperwork.c.person_id).order_by(Person.name).all(),
+                    [(u'dogbert',), (u'dogbert',), (u'pointy haired boss',)]
+                )
+
+
+            eq_(
+                sess.query(Manager).join(Paperwork, Manager.paperwork).order_by(Manager.name).all(),
                 [m1, b1]
             )
 
             eq_(
-                sess.query(Manager.name).join((paperwork, Manager.person_id==paperwork.c.person_id)).order_by(Manager.name).all(),
+                sess.query(Manager.name).join(paperwork, Manager.person_id==paperwork.c.person_id).order_by(Manager.name).all(),
                 [(u'dogbert',), (u'dogbert',), (u'pointy haired boss',)]
             )
 
             eq_(
-                sess.query(Manager.person_id).join((paperwork, Manager.person_id==paperwork.c.person_id)).order_by(Manager.name).all(),
+                sess.query(Manager.person_id).join(paperwork, Manager.person_id==paperwork.c.person_id).order_by(Manager.name).all(),
                 [(4,), (4,), (3,)]
             )
 
             eq_(
                 sess.query(Manager.name, Paperwork.description).
-                    join((Paperwork, Manager.person_id==Paperwork.person_id)).
+                    join(Paperwork, Manager.person_id==Paperwork.person_id).
                     order_by(Paperwork.paperwork_id).
                     all(),
                 [(u'pointy haired boss', u'review #1'), (u'dogbert', u'review #2'), (u'dogbert', u'review #3')]
@@ -397,7 +428,7 @@ def _produce_test(select_type):
 
             malias = aliased(Manager)
             eq_(
-                sess.query(malias.name).join((paperwork, malias.person_id==paperwork.c.person_id)).all(),
+                sess.query(malias.name).join(paperwork, malias.person_id==paperwork.c.person_id).all(),
                 [(u'pointy haired boss',), (u'dogbert',), (u'dogbert',)]
             )
 
@@ -566,19 +597,19 @@ def _produce_test(select_type):
 
         def test_join_to_subclass(self):
             sess = create_session()
-            eq_(sess.query(Company).join(('employees', people.join(engineers))).filter(Engineer.primary_language=='java').all(), [c1])
+            eq_(sess.query(Company).join(people.join(engineers), 'employees').filter(Engineer.primary_language=='java').all(), [c1])
 
             if select_type == '':
                 eq_(sess.query(Company).select_from(companies.join(people).join(engineers)).filter(Engineer.primary_language=='java').all(), [c1])
-                eq_(sess.query(Company).join(('employees', people.join(engineers))).filter(Engineer.primary_language=='java').all(), [c1])
+                eq_(sess.query(Company).join(people.join(engineers), 'employees').filter(Engineer.primary_language=='java').all(), [c1])
 
                 ealias = aliased(Engineer)
-                eq_(sess.query(Company).join(('employees', ealias)).filter(ealias.primary_language=='java').all(), [c1])
+                eq_(sess.query(Company).join(ealias, 'employees').filter(ealias.primary_language=='java').all(), [c1])
 
                 eq_(sess.query(Person).select_from(people.join(engineers)).join(Engineer.machines).all(), [e1, e2, e3])
                 eq_(sess.query(Person).select_from(people.join(engineers)).join(Engineer.machines).filter(Machine.name.ilike("%ibm%")).all(), [e1, e3])
-                eq_(sess.query(Company).join(('employees', people.join(engineers)), Engineer.machines).all(), [c1, c2])
-                eq_(sess.query(Company).join(('employees', people.join(engineers)), Engineer.machines).filter(Machine.name.ilike("%thinkpad%")).all(), [c1])
+                eq_(sess.query(Company).join(people.join(engineers), 'employees').join(Engineer.machines).all(), [c1, c2])
+                eq_(sess.query(Company).join(people.join(engineers), 'employees').join(Engineer.machines).filter(Machine.name.ilike("%thinkpad%")).all(), [c1])
             else:
                 eq_(sess.query(Company).select_from(companies.join(people).join(engineers)).filter(Engineer.primary_language=='java').all(), [c1])
                 eq_(sess.query(Company).join('employees').filter(Engineer.primary_language=='java').all(), [c1])
@@ -595,6 +626,25 @@ def _produce_test(select_type):
             eq_(sess.query(Company).join(Company.employees.of_type(Engineer)).filter(Engineer.primary_language=='java').all(), [c1])
             eq_(sess.query(Company).join(Company.employees.of_type(Engineer), 'machines').filter(Machine.name.ilike("%thinkpad%")).all(), [c1])
 
+        def test_join_to_subclass_count(self):
+            sess = create_session()
+
+            eq_(sess.query(Company, Engineer).
+                    join(Company.employees.of_type(Engineer)).
+                    filter(Engineer.primary_language=='java').count(), 
+                1)
+
+            # test [ticket:2093]
+            eq_(sess.query(Company.company_id, Engineer).
+                    join(Company.employees.of_type(Engineer)).
+                    filter(Engineer.primary_language=='java').count(), 
+                1)
+
+            eq_(sess.query(Company).
+                    join(Company.employees.of_type(Engineer)).
+                    filter(Engineer.primary_language=='java').count(), 
+                1)
+
         def test_join_through_polymorphic(self):
 
             sess = create_session()
@@ -647,10 +697,13 @@ def _produce_test(select_type):
                 c2
             )
 
-            # same, using explicit join condition.  Query.join() must adapt the on clause
-            # here to match the subquery wrapped around "people join engineers".
+            # same, using explicit join condition.  Query.join() must 
+            # adapt the on clause here to match the subquery wrapped around 
+            # "people join engineers".
             eq_(
-                sess.query(Company).join((Engineer, Company.company_id==Engineer.company_id)).filter(Engineer.engineer_name=='vlad').one(),
+                sess.query(Company).
+                    join(Engineer, Company.company_id==Engineer.company_id).
+                    filter(Engineer.engineer_name=='vlad').one(),
                 c2
             )
 
@@ -855,18 +908,17 @@ for select_type in ('', 'Polymorphic', 'Unions', 'AliasedJoins', 'Joins'):
 
 del testclass
 
-class SelfReferentialTestJoinedToBase(_base.MappedTest):
+class SelfReferentialTestJoinedToBase(fixtures.MappedTest):
     run_setup_mappers = 'once'
 
     @classmethod
     def define_tables(cls, metadata):
-        global people, engineers
-        people = Table('people', metadata,
+        Table('people', metadata,
            Column('person_id', Integer, primary_key=True, test_needs_autoincrement=True),
            Column('name', String(50)),
            Column('type', String(30)))
 
-        engineers = Table('engineers', metadata,
+        Table('engineers', metadata,
            Column('person_id', Integer, ForeignKey('people.person_id'), primary_key=True),
            Column('primary_language', String(50)),
            Column('reports_to_id', Integer, ForeignKey('people.person_id'))
@@ -874,6 +926,8 @@ class SelfReferentialTestJoinedToBase(_base.MappedTest):
 
     @classmethod
     def setup_mappers(cls):
+        engineers, people = cls.tables.engineers, cls.tables.people
+
         mapper(Person, people, polymorphic_on=people.c.type, polymorphic_identity='person')
         mapper(Engineer, engineers, inherits=Person, 
           inherit_condition=engineers.c.person_id==people.c.person_id,
@@ -915,12 +969,11 @@ class SelfReferentialTestJoinedToBase(_base.MappedTest):
             sess.query(Engineer).join('reports_to', aliased=True).filter(Person.name=='dogbert').first(), 
             Engineer(name='dilbert'))
 
-class SelfReferentialJ2JTest(_base.MappedTest):
+class SelfReferentialJ2JTest(fixtures.MappedTest):
     run_setup_mappers = 'once'
 
     @classmethod
     def define_tables(cls, metadata):
-        global people, engineers, managers
         people = Table('people', metadata,
            Column('person_id', Integer, primary_key=True, test_needs_autoincrement=True),
            Column('name', String(50)),
@@ -938,6 +991,10 @@ class SelfReferentialJ2JTest(_base.MappedTest):
 
     @classmethod
     def setup_mappers(cls):
+        engineers, managers, people = (cls.tables.engineers,
+                                cls.tables.managers,
+                                cls.tables.people)
+
         mapper(Person, people, polymorphic_on=people.c.type, polymorphic_identity='person')
         mapper(Manager, managers, inherits=Person, polymorphic_identity='manager')
 
@@ -1026,135 +1083,20 @@ class SelfReferentialJ2JTest(_base.MappedTest):
             [m1]
         )
 
-class SelfReferentialJ2JSelfTest(_base.MappedTest):
-    run_setup_mappers = 'once'
-
-    @classmethod
-    def define_tables(cls, metadata):
-        people = Table('people', metadata,
-           Column('person_id', Integer, 
-                        primary_key=True, test_needs_autoincrement=True),
-           Column('name', String(50)),
-           Column('type', String(30)))
-
-        engineers = Table('engineers', metadata,
-           Column('person_id', Integer, 
-                    ForeignKey('people.person_id'), primary_key=True),
-           Column('reports_to_id', Integer, 
-                    ForeignKey('engineers.person_id'))
-          )
 
 
-    @classmethod
-    def setup_mappers(cls):
-        engineers, people = (cls.tables.engineers,
-                                cls.tables.people)
-
-        mapper(Person, people, polymorphic_on=people.c.type, 
-                            polymorphic_identity='person')
-
-        mapper(Engineer, engineers, inherits=Person, 
-          polymorphic_identity='engineer', properties={
-          'reports_to':relationship(Engineer, 
-                            primaryjoin=engineers.c.person_id==engineers.c.reports_to_id, 
-                            backref='engineers',
-                            remote_side=engineers.c.person_id)
-        })
-
-    def _two_obj_fixture(self):
-        e1 = Engineer(name='wally')
-        e2 = Engineer(name='dilbert', 
-                        reports_to=e1)
-        sess = Session()
-        sess.add_all([e1, e2])
-        sess.commit()
-        return sess
-
-    def _five_obj_fixture(self):
-        sess =Session()
-        e1, e2, e3, e4, e5 = [
-            Engineer(name='e%d' % (i + 1)) for i in xrange(5)
-        ]
-        e3.reports_to=e1
-        e4.reports_to=e2
-        sess.add_all([e1, e2, e3, e4, e5])
-        sess.commit()
-        return sess
-
-    def test_has(self):
-        sess = self._two_obj_fixture()
-
-        eq_(
-            sess.query(Engineer).
-                filter(Engineer.reports_to.has(Engineer.name=='wally')).
-                first(), 
-            Engineer(name='dilbert'))
-
-    def test_join_explicit_alias(self):
-        sess = self._five_obj_fixture()
-
-        ea = aliased(Engineer)
-        eq_(
-            sess.query(Engineer).
-                join((ea, Engineer.engineers)).
-                filter(Engineer.name=='e1').all(),
-            [Engineer(name='e1')]
-        )
-
-    def test_join_aliased_flag_one(self):
-        sess = self._two_obj_fixture()
-
-        eq_(
-            sess.query(Engineer).
-                join('reports_to', aliased=True).
-                filter(Engineer.name=='wally').first(), 
-            Engineer(name='dilbert')
-        )
-
-    def test_join_aliased_flag_two(self):
-        sess = self._five_obj_fixture()
-
-        eq_(
-            sess.query(Engineer).
-                join(Engineer.engineers, aliased=True).
-                filter(Engineer.name=='e4').all(),
-            [Engineer(name='e2')]
-        )
-
-
-    def test_relationship_compare(self):
-        sess = self._five_obj_fixture()
-
-        eq_(
-            sess.query(Engineer).
-                join(Engineer.engineers, aliased=True).
-                filter(Engineer.reports_to==None).all(), 
-            []
-        )
-
-        e1 = sess.query(Engineer).filter_by(name='e1').one()
-        eq_(
-            sess.query(Engineer).
-                join(Engineer.engineers, aliased=True).
-                filter(Engineer.reports_to==e1).all(), 
-            [e1]
-        )
-
-
-class M2MFilterTest(_base.MappedTest):
+class M2MFilterTest(fixtures.MappedTest):
     run_setup_mappers = 'once'
     run_inserts = 'once'
     run_deletes = None
 
     @classmethod
     def define_tables(cls, metadata):
-        global people, engineers, organizations, engineers_to_org
-
         organizations = Table('organizations', metadata,
             Column('id', Integer, primary_key=True, test_needs_autoincrement=True),
             Column('name', String(50)),
             )
-        engineers_to_org = Table('engineers_org', metadata,
+        engineers_to_org = Table('engineers_to_org', metadata,
             Column('org_id', Integer, ForeignKey('organizations.id')),
             Column('engineer_id', Integer, ForeignKey('engineers.person_id')),
         )
@@ -1171,8 +1113,12 @@ class M2MFilterTest(_base.MappedTest):
 
     @classmethod
     def setup_mappers(cls):
-        global Organization
-        class Organization(_fixtures.Base):
+        organizations, people, engineers, engineers_to_org = (cls.tables.organizations,
+                                cls.tables.people,
+                                cls.tables.engineers,
+                                cls.tables.engineers_to_org)
+
+        class Organization(cls.Comparable):
             pass
 
         mapper(Organization, organizations, properties={
@@ -1184,6 +1130,8 @@ class M2MFilterTest(_base.MappedTest):
 
     @classmethod
     def insert_data(cls):
+        Organization = cls.classes.Organization
+
         e1 = Engineer(name='e1')
         e2 = Engineer(name='e2')
         e3 = Engineer(name='e3')
@@ -1197,58 +1145,85 @@ class M2MFilterTest(_base.MappedTest):
         sess.flush()
 
     def test_not_contains(self):
+        Organization = self.classes.Organization
+
         sess = create_session()
 
-        e1 = sess.query(Person).filter(Engineer.name=='e1').one()
+        e1 = sess.query(Person).filter(Engineer.name == 'e1').one()
 
         # this works
-        eq_(sess.query(Organization).filter(~Organization.engineers.of_type(Engineer).contains(e1)).all(), [Organization(name='org2')])
+
+        eq_(sess.query(Organization).filter(
+            ~Organization.engineers.of_type(Engineer).contains(e1)
+            ).all(),
+            [Organization(name='org2')])
 
         # this had a bug
-        eq_(sess.query(Organization).filter(~Organization.engineers.contains(e1)).all(), [Organization(name='org2')])
+
+        eq_(sess.query(Organization).filter(~Organization.engineers.contains(e1)).all(),
+            [Organization(name='org2')])
 
     def test_any(self):
+        Organization = self.classes.Organization
+
         sess = create_session()
-        eq_(sess.query(Organization).filter(Organization.engineers.of_type(Engineer).any(Engineer.name=='e1')).all(), [Organization(name='org1')])
-        eq_(sess.query(Organization).filter(Organization.engineers.any(Engineer.name=='e1')).all(), [Organization(name='org1')])
-
-class SelfReferentialM2MTest(_base.MappedTest, AssertsCompiledSQL):
-    run_setup_mappers = 'once'
+        eq_(sess.query(Organization).filter(Organization.engineers.of_type(Engineer).any(Engineer.name
+            == 'e1')).all(), [Organization(name='org1')])
+        eq_(sess.query(Organization).filter(Organization.engineers.any(Engineer.name
+            == 'e1')).all(), [Organization(name='org1')])
 
+class SelfReferentialM2MTest(fixtures.MappedTest, AssertsCompiledSQL):
     @classmethod
     def define_tables(cls, metadata):
-        global Parent, Child1, Child2
-
-        Base = declarative_base(metadata=metadata)
-
-        secondary_table = Table('secondary', Base.metadata,
+        Table('secondary', metadata,
            Column('left_id', Integer, ForeignKey('parent.id'), nullable=False),
            Column('right_id', Integer, ForeignKey('parent.id'), nullable=False))
 
-        class Parent(Base):
-           __tablename__ = 'parent'
-           id = Column(Integer, primary_key=True, test_needs_autoincrement=True)
-           cls = Column(String(50))
-           __mapper_args__ = dict(polymorphic_on = cls )
+        Table('parent', metadata,
+            Column('id', Integer, primary_key=True, test_needs_autoincrement=True),
+            Column('cls', String(50))
+        )
+        Table('child1', metadata,
+            Column('id', Integer, ForeignKey('parent.id'), primary_key=True)
+        )
+        Table('child2', metadata,
+            Column('id', Integer, ForeignKey('parent.id'), primary_key=True)
+        )
 
+    @classmethod
+    def setup_classes(cls):
+        class Parent(cls.Basic):
+            pass
         class Child1(Parent):
-           __tablename__ = 'child1'
-           id = Column(Integer, ForeignKey('parent.id'), primary_key=True)
-           __mapper_args__ = dict(polymorphic_identity = 'child1')
-
+            pass
         class Child2(Parent):
-           __tablename__ = 'child2'
-           id = Column(Integer, ForeignKey('parent.id'), primary_key=True)
-           __mapper_args__ = dict(polymorphic_identity = 'child2')
+            pass
 
-        Child1.left_child2 = relationship(Child2, secondary = secondary_table,
-               primaryjoin = Parent.id == secondary_table.c.right_id,
-               secondaryjoin = Parent.id == secondary_table.c.left_id,
-               uselist = False, backref="right_children"
+    @classmethod
+    def setup_mappers(cls):
+        child1, child2, Parent, parent, Child1, Child2, secondary = (cls.tables.child1,
+                                cls.tables.child2,
+                                cls.classes.Parent,
+                                cls.tables.parent,
+                                cls.classes.Child1,
+                                cls.classes.Child2,
+                                cls.tables.secondary)
+
+        mapper(Parent, parent, polymorphic_on=parent.c.cls)
+        mapper(Child1, child1, inherits=Parent, polymorphic_identity='child1', properties={
+            'left_child2' : relationship(Child2, 
+                                secondary = secondary,
+                                primaryjoin = parent.c.id == secondary.c.right_id,
+                                secondaryjoin = parent.c.id == secondary.c.left_id,
+                                uselist = False, backref="right_children"
                                )
 
+        })
+        mapper(Child2, child2, inherits=Parent, polymorphic_identity = 'child2')
 
     def test_query_crit(self):
+        Child1, Child2 = self.classes.Child1, self.classes.Child2
+
         session = create_session()
         c11, c12, c13 = Child1(), Child1(), Child1()
         c21, c22, c23 = Child2(), Child2(), Child2()
@@ -1280,7 +1255,7 @@ class SelfReferentialM2MTest(_base.MappedTest, AssertsCompiledSQL):
         # test the same again
         self.assert_compile(
             session.query(Child2).join(Child2.right_children).filter(Child1.left_child2==c22).with_labels().statement,
-            "SELECT parent.id AS parent_id, child2.id AS child2_id, parent.cls AS parent_cls FROM "
+            "SELECT child2.id AS child2_id, parent.id AS parent_id, parent.cls AS parent_cls FROM "
             "secondary AS secondary_1, parent JOIN child2 ON parent.id = child2.id JOIN secondary AS secondary_2 "
             "ON parent.id = secondary_2.left_id JOIN (SELECT parent.id AS parent_id, parent.cls AS parent_cls, "
             "child1.id AS child1_id FROM parent JOIN child1 ON parent.id = child1.id) AS anon_1 ON "
@@ -1289,6 +1264,8 @@ class SelfReferentialM2MTest(_base.MappedTest, AssertsCompiledSQL):
         )
 
     def test_eager_join(self):
+        Child1, Child2 = self.classes.Child1, self.classes.Child2
+
         session = create_session()
 
         c1 = Child1()
@@ -1300,15 +1277,16 @@ class SelfReferentialM2MTest(_base.MappedTest, AssertsCompiledSQL):
 
         # test that the splicing of the join works here, doesnt break in the middle of "parent join child1"
         self.assert_compile(q.limit(1).with_labels().statement, 
-        "SELECT anon_1.parent_id AS anon_1_parent_id, anon_1.child1_id AS anon_1_child1_id, "\
-        "anon_1.parent_cls AS anon_1_parent_cls, anon_2.parent_id AS anon_2_parent_id, "\
-        "anon_2.child2_id AS anon_2_child2_id, anon_2.parent_cls AS anon_2_parent_cls FROM "\
-        "(SELECT parent.id AS parent_id, child1.id AS child1_id, parent.cls AS parent_cls FROM parent "\
-        "JOIN child1 ON parent.id = child1.id  LIMIT 1) AS anon_1 LEFT OUTER JOIN secondary AS secondary_1 "\
+        "SELECT anon_1.child1_id AS anon_1_child1_id, anon_1.parent_id AS anon_1_parent_id, "\
+        "anon_1.parent_cls AS anon_1_parent_cls, anon_2.child2_id AS anon_2_child2_id, "\
+        "anon_2.parent_id AS anon_2_parent_id, anon_2.parent_cls AS anon_2_parent_cls FROM "\
+        "(SELECT child1.id AS child1_id, parent.id AS parent_id, parent.cls AS parent_cls FROM parent "\
+        "JOIN child1 ON parent.id = child1.id LIMIT :param_1) AS anon_1 LEFT OUTER JOIN secondary AS secondary_1 "\
         "ON anon_1.parent_id = secondary_1.right_id LEFT OUTER JOIN (SELECT parent.id AS parent_id, "\
         "parent.cls AS parent_cls, child2.id AS child2_id FROM parent JOIN child2 ON parent.id = child2.id) "\
-        "AS anon_2 ON anon_2.parent_id = secondary_1.left_id"
-        , dialect=default.DefaultDialect())
+        "AS anon_2 ON anon_2.parent_id = secondary_1.left_id",
+        {'param_1':1},
+        dialect=default.DefaultDialect())
 
         # another way to check
         assert q.limit(1).with_labels().subquery().count().scalar() == 1
@@ -1316,6 +1294,8 @@ class SelfReferentialM2MTest(_base.MappedTest, AssertsCompiledSQL):
         assert q.first() is c1
 
     def test_subquery_load(self):
+        Child1, Child2 = self.classes.Child1, self.classes.Child2
+
         session = create_session()
 
         c1 = Child1()
@@ -1327,7 +1307,7 @@ class SelfReferentialM2MTest(_base.MappedTest, AssertsCompiledSQL):
         for row in session.query(Child1).options(subqueryload('left_child2')).all():
             assert row.left_child2
 
-class EagerToSubclassTest(_base.MappedTest):
+class EagerToSubclassTest(fixtures.MappedTest):
     """Test eager loads to subclass mappers"""
 
     run_setup_classes = 'once'
@@ -1364,23 +1344,30 @@ class EagerToSubclassTest(_base.MappedTest):
         )
 
     @classmethod
-    @testing.resolve_artifact_names
     def setup_classes(cls):
-        class Parent(_base.ComparableEntity):
+        class Parent(cls.Comparable):
             pass
 
-        class Base(_base.ComparableEntity):
+        class Base(cls.Comparable):
             pass
 
         class Sub(Base):
             pass
 
-        class Related(_base.ComparableEntity):
+        class Related(cls.Comparable):
             pass
 
     @classmethod
-    @testing.resolve_artifact_names
     def setup_mappers(cls):
+        Base, sub, parent, related, base, Related, Parent, Sub = (cls.classes.Base,
+                                cls.tables.sub,
+                                cls.tables.parent,
+                                cls.tables.related,
+                                cls.tables.base,
+                                cls.classes.Related,
+                                cls.classes.Parent,
+                                cls.classes.Sub)
+
         mapper(Parent, parent, properties={
             'children':relationship(Sub, order_by=sub.c.data)
         })
@@ -1395,8 +1382,11 @@ class EagerToSubclassTest(_base.MappedTest):
         mapper(Related, related)
 
     @classmethod
-    @testing.resolve_artifact_names
     def insert_data(cls):
+        Parent, Sub, Related = (cls.classes.Parent,
+                                cls.classes.Sub,
+                                cls.classes.Related)
+
         sess = Session()
         r1, r2 = Related(data='r1'), Related(data='r2')
         s1, s2, s3 = Sub(data='s1', related=r1), \
@@ -1410,8 +1400,9 @@ class EagerToSubclassTest(_base.MappedTest):
         sess.add(p2)
         sess.commit()
 
-    @testing.resolve_artifact_names
     def test_joinedload(self):
+        Sub, Parent = self.classes.Sub, self.classes.Parent
+
         sess = Session()
         def go():
             eq_(
@@ -1431,8 +1422,9 @@ class EagerToSubclassTest(_base.MappedTest):
             )
         self.assert_sql_count(testing.db, go, 1)
 
-    @testing.resolve_artifact_names
     def test_contains_eager(self):
+        Sub, Parent = self.classes.Sub, self.classes.Parent
+
         sess = Session()
         def go():
             eq_(
@@ -1453,8 +1445,11 @@ class EagerToSubclassTest(_base.MappedTest):
             )
         self.assert_sql_count(testing.db, go, 1)
 
-    @testing.resolve_artifact_names
     def test_subq_through_related(self):
+        Related, Parent, Sub = (self.classes.Related,
+                                self.classes.Parent,
+                                self.classes.Sub)
+
         sess = Session()
         def go():
             eq_(
@@ -1478,7 +1473,7 @@ class EagerToSubclassTest(_base.MappedTest):
             )
         self.assert_sql_count(testing.db, go, 3)
 
-class SubClassEagerToSubClassTest(_base.MappedTest):
+class SubClassEagerToSubClassTest(fixtures.MappedTest):
     """Test joinedloads from subclass to subclass mappers"""
 
     run_setup_classes = 'once'
@@ -1510,23 +1505,30 @@ class SubClassEagerToSubClassTest(_base.MappedTest):
         )
 
     @classmethod
-    @testing.resolve_artifact_names
     def setup_classes(cls):
-        class Parent(_base.ComparableEntity):
+        class Parent(cls.Comparable):
             pass
 
         class Subparent(Parent):
             pass
 
-        class Base(_base.ComparableEntity):
+        class Base(cls.Comparable):
             pass
 
         class Sub(Base):
             pass
 
     @classmethod
-    @testing.resolve_artifact_names
     def setup_mappers(cls):
+        Sub, parent, subparent, Subparent, Base, base, Parent, sub = (cls.classes.Sub,
+                                cls.tables.parent,
+                                cls.tables.subparent,
+                                cls.classes.Subparent,
+                                cls.classes.Base,
+                                cls.tables.base,
+                                cls.classes.Parent,
+                                cls.tables.sub)
+
         mapper(Parent, parent, polymorphic_on=parent.c.type, polymorphic_identity='b')
         mapper(Subparent, subparent, inherits=Parent, polymorphic_identity='s', properties={
             'children':relationship(Sub, order_by=base.c.id)
@@ -1535,8 +1537,9 @@ class SubClassEagerToSubClassTest(_base.MappedTest):
         mapper(Sub, sub, inherits=Base, polymorphic_identity='s')
 
     @classmethod
-    @testing.resolve_artifact_names
     def insert_data(cls):
+        Sub, Subparent = cls.classes.Sub, cls.classes.Subparent
+
         sess = create_session()
         p1 = Subparent(data='p1', children=[Sub(data='s1'), Sub(data='s2'), Sub(data='s3')])
         p2 = Subparent(data='p2', children=[Sub(data='s4'), Sub(data='s5')])
@@ -1544,8 +1547,9 @@ class SubClassEagerToSubClassTest(_base.MappedTest):
         sess.add(p2)
         sess.flush()
 
-    @testing.resolve_artifact_names
     def test_joinedload(self):
+        Sub, Subparent = self.classes.Sub, self.classes.Subparent
+
         sess = create_session()
         def go():
             eq_(
@@ -1568,8 +1572,9 @@ class SubClassEagerToSubClassTest(_base.MappedTest):
             )
         self.assert_sql_count(testing.db, go, 1)
 
-    @testing.resolve_artifact_names
     def test_contains_eager(self):
+        Sub, Subparent = self.classes.Sub, self.classes.Subparent
+
         sess = create_session()
         def go():
             eq_(
@@ -1592,8 +1597,9 @@ class SubClassEagerToSubClassTest(_base.MappedTest):
             )
         self.assert_sql_count(testing.db, go, 1)
 
-    @testing.resolve_artifact_names
     def test_subqueryload(self):
+        Sub, Subparent = self.classes.Sub, self.classes.Subparent
+
         sess = create_session()
         def go():
             eq_(
