@@ -1,25 +1,30 @@
-from sqlalchemy.test.testing import eq_, is_, is_not_
-from sqlalchemy.test import testing
-from sqlalchemy.test.schema import Table, Column
+from test.lib.testing import eq_, is_, is_not_
+from test.lib import testing
+from test.lib.schema import Table, Column
 from sqlalchemy import Integer, String, ForeignKey, bindparam
 from sqlalchemy.orm import backref, subqueryload, subqueryload_all, \
     mapper, relationship, clear_mappers, create_session, lazyload, \
     aliased, joinedload, deferred, undefer, eagerload_all
-from sqlalchemy.test.testing import eq_, assert_raises, \
+from test.lib.testing import eq_, assert_raises, \
     assert_raises_message
-from sqlalchemy.test.assertsql import CompiledSQL
-from test.orm import _base, _fixtures
+from test.lib.assertsql import CompiledSQL
+from test.lib import fixtures
+from test.orm import _fixtures
 import sqlalchemy as sa
 
 class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
     run_inserts = 'once'
     run_deletes = None
 
-    @testing.resolve_artifact_names
     def test_basic(self):
+        users, Address, addresses, User = (self.tables.users,
+                                self.classes.Address,
+                                self.tables.addresses,
+                                self.classes.User)
+
         mapper(User, users, properties={
             'addresses':relationship(
-                            mapper(Address, addresses), 
+                            mapper(Address, addresses),
                             order_by=Address.id)
         })
         sess = create_session()
@@ -35,15 +40,21 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
 
         self.assert_sql_count(testing.db, go, 2)
 
-        def go(): 
+        def go():
             eq_(
-                self.static.user_address_result, 
+                self.static.user_address_result,
                 q.order_by(User.id).all()
             )
         self.assert_sql_count(testing.db, go, 2)
 
-    @testing.resolve_artifact_names
     def test_from_aliased(self):
+        users, Dingaling, User, dingalings, Address, addresses = (self.tables.users,
+                                self.classes.Dingaling,
+                                self.classes.User,
+                                self.tables.dingalings,
+                                self.classes.Address,
+                                self.tables.addresses)
+
         mapper(Dingaling, dingalings)
         mapper(Address, addresses, properties={
             'dingalings':relationship(Dingaling, order_by=Dingaling.id)
@@ -68,9 +79,9 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
 
         self.assert_sql_count(testing.db, go, 2)
 
-        def go(): 
+        def go():
             eq_(
-                self.static.user_address_result, 
+                self.static.user_address_result,
                 q.order_by(u.id).all()
             )
         self.assert_sql_count(testing.db, go, 2)
@@ -95,11 +106,15 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
         self.assert_sql_count(testing.db, go, 3)
 
 
-    @testing.resolve_artifact_names
     def test_from_get(self):
+        users, Address, addresses, User = (self.tables.users,
+                                self.classes.Address,
+                                self.tables.addresses,
+                                self.classes.User)
+
         mapper(User, users, properties={
             'addresses':relationship(
-                            mapper(Address, addresses), 
+                            mapper(Address, addresses),
                             order_by=Address.id)
         })
         sess = create_session()
@@ -114,11 +129,15 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
 
         self.assert_sql_count(testing.db, go, 2)
 
-    @testing.resolve_artifact_names
     def test_from_params(self):
+        users, Address, addresses, User = (self.tables.users,
+                                self.classes.Address,
+                                self.tables.addresses,
+                                self.classes.User)
+
         mapper(User, users, properties={
             'addresses':relationship(
-                            mapper(Address, addresses), 
+                            mapper(Address, addresses),
                             order_by=Address.id)
         })
         sess = create_session()
@@ -133,10 +152,15 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
 
         self.assert_sql_count(testing.db, go, 2)
 
-    @testing.resolve_artifact_names
     def test_disable_dynamic(self):
         """test no subquery option on a dynamic."""
 
+        users, Address, addresses, User = (self.tables.users,
+                                self.classes.Address,
+                                self.tables.addresses,
+                                self.classes.User)
+
+
         mapper(User, users, properties={
             'addresses':relationship(Address, lazy="dynamic")
         })
@@ -151,8 +175,13 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
             sess.query(User).options(subqueryload(User.addresses)).first,
         )
 
-    @testing.resolve_artifact_names
-    def test_many_to_many(self):
+    def test_many_to_many_plain(self):
+        keywords, items, item_keywords, Keyword, Item = (self.tables.keywords,
+                                self.tables.items,
+                                self.tables.item_keywords,
+                                self.classes.Keyword,
+                                self.classes.Item)
+
         mapper(Keyword, keywords)
         mapper(Item, items, properties = dict(
                 keywords = relationship(Keyword, secondary=item_keywords,
@@ -163,21 +192,51 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
             eq_(self.static.item_keyword_result, q.all())
         self.assert_sql_count(testing.db, go, 2)
 
+    def test_many_to_many_with_join(self):
+        keywords, items, item_keywords, Keyword, Item = (self.tables.keywords,
+                                self.tables.items,
+                                self.tables.item_keywords,
+                                self.classes.Keyword,
+                                self.classes.Item)
+
+        mapper(Keyword, keywords)
+        mapper(Item, items, properties = dict(
+                keywords = relationship(Keyword, secondary=item_keywords,
+                                    lazy='subquery', order_by=keywords.c.id)))
+
+        q = create_session().query(Item).order_by(Item.id)
         def go():
             eq_(self.static.item_keyword_result[0:2],
                 q.join('keywords').filter(Keyword.name == 'red').all())
         self.assert_sql_count(testing.db, go, 2)
 
+    def test_many_to_many_with_join_alias(self):
+        keywords, items, item_keywords, Keyword, Item = (self.tables.keywords,
+                                self.tables.items,
+                                self.tables.item_keywords,
+                                self.classes.Keyword,
+                                self.classes.Item)
+
+        mapper(Keyword, keywords)
+        mapper(Item, items, properties = dict(
+                keywords = relationship(Keyword, secondary=item_keywords,
+                                    lazy='subquery', order_by=keywords.c.id)))
+
+        q = create_session().query(Item).order_by(Item.id)
         def go():
             eq_(self.static.item_keyword_result[0:2],
                 (q.join('keywords', aliased=True).
                  filter(Keyword.name == 'red')).all())
         self.assert_sql_count(testing.db, go, 2)
 
-    @testing.resolve_artifact_names
     def test_orderby(self):
+        users, Address, addresses, User = (self.tables.users,
+                                self.classes.Address,
+                                self.tables.addresses,
+                                self.classes.User)
+
         mapper(User, users, properties = {
-            'addresses':relationship(mapper(Address, addresses), 
+            'addresses':relationship(mapper(Address, addresses),
                         lazy='subquery', order_by=addresses.c.email_address),
         })
         q = create_session().query(User)
@@ -196,11 +255,15 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
             User(id=10, addresses=[])
         ], q.order_by(User.id).all())
 
-    @testing.resolve_artifact_names
     def test_orderby_multi(self):
+        users, Address, addresses, User = (self.tables.users,
+                                self.classes.Address,
+                                self.tables.addresses,
+                                self.classes.User)
+
         mapper(User, users, properties = {
-            'addresses':relationship(mapper(Address, addresses), 
-                            lazy='subquery', 
+            'addresses':relationship(mapper(Address, addresses),
+                            lazy='subquery',
                             order_by=[
                                     addresses.c.email_address,
                                     addresses.c.id]),
@@ -221,14 +284,19 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
             User(id=10, addresses=[])
         ], q.order_by(User.id).all())
 
-    @testing.resolve_artifact_names
     def test_orderby_related(self):
-        """A regular mapper select on a single table can 
+        """A regular mapper select on a single table can
             order by a relationship to a second table"""
 
+        Address, addresses, users, User = (self.classes.Address,
+                                self.tables.addresses,
+                                self.tables.users,
+                                self.classes.User)
+
+
         mapper(Address, addresses)
         mapper(User, users, properties = dict(
-            addresses = relationship(Address, 
+            addresses = relationship(Address,
                                         lazy='subquery',
                                         order_by=addresses.c.id),
         ))
@@ -251,8 +319,12 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
             ]),
         ], l)
 
-    @testing.resolve_artifact_names
     def test_orderby_desc(self):
+        Address, addresses, users, User = (self.classes.Address,
+                                self.tables.addresses,
+                                self.tables.users,
+                                self.classes.User)
+
         mapper(Address, addresses)
         mapper(User, users, properties = dict(
             addresses = relationship(Address, lazy='subquery',
@@ -294,24 +366,34 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
     def test_mapper_pathing(self):
         self._do_mapper_test(self._pathing_runs)
 
-    @testing.resolve_artifact_names
     def _do_options_test(self, configs):
+        users, Keyword, orders, items, order_items, Order, Item, User, keywords, item_keywords = (self.tables.users,
+                                self.classes.Keyword,
+                                self.tables.orders,
+                                self.tables.items,
+                                self.tables.order_items,
+                                self.classes.Order,
+                                self.classes.Item,
+                                self.classes.User,
+                                self.tables.keywords,
+                                self.tables.item_keywords)
+
         mapper(User, users, properties={
             'orders':relationship(Order, order_by=orders.c.id), # o2m, m2o
         })
         mapper(Order, orders, properties={
-            'items':relationship(Item, 
+            'items':relationship(Item,
                         secondary=order_items, order_by=items.c.id),  #m2m
         })
         mapper(Item, items, properties={
-            'keywords':relationship(Keyword, 
+            'keywords':relationship(Keyword,
                                         secondary=item_keywords,
                                         order_by=keywords.c.id) #m2m
         })
         mapper(Keyword, keywords)
 
         callables = {
-                        'joinedload':joinedload, 
+                        'joinedload':joinedload,
                     'subqueryload':subqueryload
                 }
 
@@ -326,8 +408,18 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
 
             self._do_query_tests(options, count)
 
-    @testing.resolve_artifact_names
     def _do_mapper_test(self, configs):
+        users, Keyword, orders, items, order_items, Order, Item, User, keywords, item_keywords = (self.tables.users,
+                                self.classes.Keyword,
+                                self.tables.orders,
+                                self.tables.items,
+                                self.tables.order_items,
+                                self.classes.Order,
+                                self.classes.Item,
+                                self.classes.User,
+                                self.tables.keywords,
+                                self.tables.item_keywords)
+
         opts = {
             'lazyload':'select',
             'joinedload':'joined',
@@ -336,14 +428,14 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
 
         for o, i, k, count in configs:
             mapper(User, users, properties={
-                'orders':relationship(Order, lazy=opts[o], order_by=orders.c.id), 
+                'orders':relationship(Order, lazy=opts[o], order_by=orders.c.id),
             })
             mapper(Order, orders, properties={
-                'items':relationship(Item, 
-                            secondary=order_items, lazy=opts[i], order_by=items.c.id), 
+                'items':relationship(Item,
+                            secondary=order_items, lazy=opts[i], order_by=items.c.id),
             })
             mapper(Item, items, properties={
-                'keywords':relationship(Keyword, 
+                'keywords':relationship(Keyword,
                                             lazy=opts[k],
                                             secondary=item_keywords,
                                             order_by=keywords.c.id)
@@ -355,8 +447,9 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
             finally:
                 clear_mappers()
 
-    @testing.resolve_artifact_names
     def _do_query_tests(self, opts, count):
+        Order, User = self.classes.Order, self.classes.User
+
         sess = create_session()
         def go():
             eq_(
@@ -380,10 +473,15 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
         )
 
 
-    @testing.resolve_artifact_names
     def test_cyclical(self):
         """A circular eager relationship breaks the cycle with a lazy loader"""
 
+        Address, addresses, users, User = (self.classes.Address,
+                                self.tables.addresses,
+                                self.tables.users,
+                                self.classes.User)
+
+
         mapper(Address, addresses)
         mapper(User, users, properties = dict(
             addresses = relationship(Address, lazy='subquery',
@@ -396,11 +494,18 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
         sess = create_session()
         eq_(self.static.user_address_result, sess.query(User).order_by(User.id).all())
 
-    @testing.resolve_artifact_names
     def test_double(self):
-        """Eager loading with two relationships simultaneously, 
+        """Eager loading with two relationships simultaneously,
             from the same table, using aliases."""
 
+        users, orders, User, Address, Order, addresses = (self.tables.users,
+                                self.tables.orders,
+                                self.classes.User,
+                                self.classes.Address,
+                                self.classes.Order,
+                                self.tables.addresses)
+
+
         openorders = sa.alias(orders, 'openorders')
         closedorders = sa.alias(orders, 'closedorders')
 
@@ -451,11 +556,21 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
             ], q.all())
         self.assert_sql_count(testing.db, go, 4)
 
-    @testing.resolve_artifact_names
     def test_double_same_mappers(self):
-        """Eager loading with two relationships simulatneously, 
+        """Eager loading with two relationships simulatneously,
         from the same table, using aliases."""
 
+        addresses, items, order_items, orders, Item, User, Address, Order, users = (self.tables.addresses,
+                                self.tables.items,
+                                self.tables.order_items,
+                                self.tables.orders,
+                                self.classes.Item,
+                                self.classes.User,
+                                self.classes.Address,
+                                self.classes.Order,
+                                self.tables.users)
+
+
         mapper(Address, addresses)
         mapper(Order, orders, properties={
             'items': relationship(Item, secondary=order_items, lazy='subquery',
@@ -519,18 +634,28 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
         self.assert_sql_count(testing.db, go, 6)
 
     @testing.fails_on('maxdb', 'FIXME: unknown')
-    @testing.resolve_artifact_names
     def test_limit(self):
         """Limit operations combined with lazy-load relationships."""
 
+        users, items, order_items, orders, Item, User, Address, Order, addresses = (self.tables.users,
+                                self.tables.items,
+                                self.tables.order_items,
+                                self.tables.orders,
+                                self.classes.Item,
+                                self.classes.User,
+                                self.classes.Address,
+                                self.classes.Order,
+                                self.tables.addresses)
+
+
         mapper(Item, items)
         mapper(Order, orders, properties={
             'items':relationship(Item, secondary=order_items, lazy='subquery',
                 order_by=items.c.id)
         })
         mapper(User, users, properties={
-            'addresses':relationship(mapper(Address, addresses), 
-                            lazy='subquery', 
+            'addresses':relationship(mapper(Address, addresses),
+                            lazy='subquery',
                             order_by=addresses.c.id),
             'orders':relationship(Order, lazy='select', order_by=orders.c.id)
         })
@@ -545,26 +670,14 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
         l = q.order_by(sa.desc(User.id)).limit(2).offset(2).all()
         eq_(list(reversed(self.static.user_all_result[0:2])), l)
 
-    @testing.resolve_artifact_names
-    def test_mapper_order_by(self):
-
-        mapper(Address, addresses)
-        mapper(User, users, properties={
-            'addresses':relationship(Address,
-                            lazy='subquery',
-                            order_by=addresses.c.id),
-        },order_by=users.c.id.desc())
-
-        sess = create_session()
-        q = sess.query(User)
-
-        l = q.limit(2).all()
-        eq_(l, list(reversed(self.static.user_address_result[2:4])))
-
-    @testing.resolve_artifact_names
     def test_one_to_many_scalar(self):
+        Address, addresses, users, User = (self.classes.Address,
+                                self.tables.addresses,
+                                self.tables.users,
+                                self.classes.User)
+
         mapper(User, users, properties = dict(
-            address = relationship(mapper(Address, addresses), 
+            address = relationship(mapper(Address, addresses),
                                     lazy='subquery', uselist=False)
         ))
         q = create_session().query(User)
@@ -575,8 +688,12 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
         self.assert_sql_count(testing.db, go, 2)
 
     @testing.fails_on('maxdb', 'FIXME: unknown')
-    @testing.resolve_artifact_names
     def test_many_to_one(self):
+        users, Address, addresses, User = (self.tables.users,
+                                self.classes.Address,
+                                self.tables.addresses,
+                                self.classes.User)
+
         mapper(Address, addresses, properties = dict(
             user = relationship(mapper(User, users), lazy='subquery')
         ))
@@ -590,8 +707,12 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
             is_(a.user, u1)
         self.assert_sql_count(testing.db, go, 2)
 
-    @testing.resolve_artifact_names
     def test_double_with_aggregate(self):
+        User, users, orders, Order = (self.classes.User,
+                                self.tables.users,
+                                self.tables.orders,
+                                self.classes.Order)
+
         max_orders_by_user = sa.select([sa.func.max(orders.c.id).label('order_id')],
                                        group_by=[orders.c.user_id]
                                      ).alias('max_orders_by_user')
@@ -604,7 +725,7 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
                'orders':relationship(Order, backref='user', lazy='subquery',
                                             order_by=orders.c.id),
                'max_order':relationship(
-                                mapper(Order, max_orders, non_primary=True), 
+                                mapper(Order, max_orders, non_primary=True),
                                 lazy='subquery', uselist=False)
                })
 
@@ -627,11 +748,16 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
             ], q.order_by(User.id).all())
         self.assert_sql_count(testing.db, go, 3)
 
-    @testing.resolve_artifact_names 
     def test_uselist_false_warning(self):
-        """test that multiple rows received by a 
+        """test that multiple rows received by a
         uselist=False raises a warning."""
 
+        User, users, orders, Order = (self.classes.User,
+                                self.tables.users,
+                                self.tables.orders,
+                                self.classes.Order)
+
+
         mapper(User, users, properties={
             'order':relationship(Order, uselist=False)
         })
@@ -640,7 +766,7 @@ class EagerTest(_fixtures.FixtureTest, testing.AssertsCompiledSQL):
         assert_raises(sa.exc.SAWarning,
                 s.query(User).options(subqueryload(User.order)).all)
 
-class OrderBySecondaryTest(_base.MappedTest):
+class OrderBySecondaryTest(fixtures.MappedTest):
     @classmethod
     def define_tables(cls, metadata):
         Table('m2m', metadata,
@@ -676,10 +802,13 @@ class OrderBySecondaryTest(_base.MappedTest):
                  (3, 1, 2),
                  (5, 2, 3)))
 
-    @testing.resolve_artifact_names
     def test_ordering(self):
-        class A(_base.ComparableEntity):pass
-        class B(_base.ComparableEntity):pass
+        a, m2m, b = (self.tables.a,
+                                self.tables.m2m,
+                                self.tables.b)
+
+        class A(fixtures.ComparableEntity):pass
+        class B(fixtures.ComparableEntity):pass
 
         mapper(A, a, properties={
             'bs':relationship(B, secondary=m2m, lazy='subquery', order_by=m2m.c.id)
@@ -694,7 +823,7 @@ class OrderBySecondaryTest(_base.MappedTest):
             ])
         self.assert_sql_count(testing.db, go, 2)
 
-class SelfReferentialTest(_base.MappedTest):
+class SelfReferentialTest(fixtures.MappedTest):
     @classmethod
     def define_tables(cls, metadata):
         Table('nodes', metadata,
@@ -703,15 +832,16 @@ class SelfReferentialTest(_base.MappedTest):
             Column('data', String(30)))
 
     @testing.fails_on('maxdb', 'FIXME: unknown')
-    @testing.resolve_artifact_names
     def test_basic(self):
-        class Node(_base.ComparableEntity):
+        nodes = self.tables.nodes
+
+        class Node(fixtures.ComparableEntity):
             def append(self, node):
                 self.children.append(node)
 
         mapper(Node, nodes, properties={
-            'children':relationship(Node, 
-                                        lazy='subquery', 
+            'children':relationship(Node,
+                                        lazy='subquery',
                                         join_depth=3, order_by=nodes.c.id)
         })
         sess = create_session()
@@ -754,9 +884,10 @@ class SelfReferentialTest(_base.MappedTest):
 
 
 
-    @testing.resolve_artifact_names
     def test_lazy_fallback_doesnt_affect_eager(self):
-        class Node(_base.ComparableEntity):
+        nodes = self.tables.nodes
+
+        class Node(fixtures.ComparableEntity):
             def append(self, node):
                 self.children.append(node)
 
@@ -787,9 +918,10 @@ class SelfReferentialTest(_base.MappedTest):
             ], list(n12.children))
         self.assert_sql_count(testing.db, go, 4)
 
-    @testing.resolve_artifact_names
     def test_with_deferred(self):
-        class Node(_base.ComparableEntity):
+        nodes = self.tables.nodes
+
+        class Node(fixtures.ComparableEntity):
             def append(self, node):
                 self.children.append(node)
 
@@ -807,7 +939,7 @@ class SelfReferentialTest(_base.MappedTest):
         sess.expunge_all()
 
         def go():
-            eq_( 
+            eq_(
                 Node(data='n1', children=[Node(data='n11'), Node(data='n12')]),
                 sess.query(Node).order_by(Node.id).first(),
                 )
@@ -829,9 +961,10 @@ class SelfReferentialTest(_base.MappedTest):
         self.assert_sql_count(testing.db, go, 3)
 
 
-    @testing.resolve_artifact_names
     def test_options(self):
-        class Node(_base.ComparableEntity):
+        nodes = self.tables.nodes
+
+        class Node(fixtures.ComparableEntity):
             def append(self, node):
                 self.children.append(node)
 
@@ -864,10 +997,12 @@ class SelfReferentialTest(_base.MappedTest):
         self.assert_sql_count(testing.db, go, 3)
 
     @testing.fails_on('maxdb', 'FIXME: unknown')
-    @testing.resolve_artifact_names
     def test_no_depth(self):
         """no join depth is set, so no eager loading occurs."""
-        class Node(_base.ComparableEntity):
+
+        nodes = self.tables.nodes
+
+        class Node(fixtures.ComparableEntity):
             def append(self, node):
                 self.children.append(node)
 
